@@ -6,12 +6,12 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either version
-  2 of the Licence, or (at your option) any later version.
+  2.1 of the Licence, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
@@ -20,10 +20,11 @@
 
 #include "context.h"
 
-#include <QtCore/QStringList>
-
+#include "rendercontext.h"
 #include "util.h"
 
+#include <QtCore/QStringList>
+
 using namespace Grantlee;
 
 namespace Grantlee
@@ -34,11 +35,17 @@ class ContextPrivate
       : q_ptr( context ),
         m_autoescape( true ),
         m_mutating( false ),
-        m_urlType( Context::AbsoluteUrls )
+        m_urlType( Context::AbsoluteUrls ),
+        m_renderContext( new RenderContext )
   {
     m_variantHashStack.append( variantHash );
   }
 
+  ~ContextPrivate()
+  {
+    delete m_renderContext;
+  }
+
   Q_DECLARE_PUBLIC( Context )
   Context * const q_ptr;
 
@@ -48,6 +55,7 @@ class ContextPrivate
   QList<QPair<QString, QString> > m_externalMedia;
   Context::UrlType m_urlType;
   QString m_relativeMediaPath;
+  RenderContext * const m_renderContext;
 };
 
 }
@@ -203,4 +211,10 @@ QString Context::relativeMediaPath() const
   return d->m_relativeMediaPath;
 }
 
+RenderContext* Context::renderContext() const
+{
+  Q_D( const Context );
+  return d->m_renderContext;
+}
+
 
