@@ -6,12 +6,12 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either version
-  2 of the Licence, or (at your option) any later version.
+  2.1 of the Licence, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
@@ -20,13 +20,14 @@
 
 #include "filterexpression.h"
 
-#include <QtCore/QBuffer>
-
-#include "parser.h"
-#include "filter.h"
-#include "util.h"
 #include "exception.h"
+#include "filter.h"
 #include "grantlee_latin1literal_p.h"
+#include "metatype.h"
+#include "parser.h"
+#include "util.h"
+
+#include <QtCore/QBuffer>
 
 typedef QPair<Grantlee::Filter::Ptr, Grantlee::Variable > ArgFilter;
 
@@ -52,47 +53,44 @@ class FilterExpressionPrivate
 
 using namespace Grantlee;
 
-static const QLatin1Char FILTER_SEPARATOR( '|' );
-static const QLatin1Char FILTER_ARGUMENT_SEPARATOR( ':' );
+static const char FILTER_SEPARATOR = '|';
+static const char FILTER_ARGUMENT_SEPARATOR = ':';
 
-static const QString filterSep( QRegExp::escape( QChar( FILTER_SEPARATOR ) ) );
-static const QString argSep( QRegExp::escape( QChar( FILTER_ARGUMENT_SEPARATOR ) ) );
+static QRegExp getFilterRegexp()
+{
+  const QString filterSep( QRegExp::escape( QChar( FILTER_SEPARATOR ) ) );
+  const QString argSep( QRegExp::escape( QChar( FILTER_ARGUMENT_SEPARATOR ) ) );
 
-static const QLatin1Literal varChars( "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_." );
-static const QLatin1Literal numChars( "[-+\\.]?\\d[\\d\\.e]*" );
-static const QString i18nOpen( QRegExp::escape( QLatin1String( "_(" ) ) );
-static const QLatin1Literal doubleQuoteStringLiteral( "\"[^\"\\\\]*(?:\\\\.[^\"\\\\]*)*\"" );
-static const QLatin1Literal singleQuoteStringLiteral( "\'[^\'\\\\]*(?:\\\\.[^\'\\\\]*)*\'" );
-static const QString i18nClose( QRegExp::escape( QLatin1String( ")" ) ) );
+  const QLatin1Literal varChars( "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_." );
+  const QLatin1Literal numChars( "[-+\\.]?\\d[\\d\\.e]*" );
+  const QString i18nOpen( QRegExp::escape( QLatin1String( "_(" ) ) );
+  const QLatin1Literal doubleQuoteStringLiteral( "\"[^\"\\\\]*(?:\\\\.[^\"\\\\]*)*\"" );
+  const QLatin1Literal singleQuoteStringLiteral( "\'[^\'\\\\]*(?:\\\\.[^\'\\\\]*)*\'" );
+  const QString i18nClose( QRegExp::escape( QLatin1String( ")" ) ) );
 
-static const
-#if QT_VERSION < 0x040600
-QStringBuilder<QStringBuilder<QStringBuilder<QStringBuilder<QStringBuilder<QStringBuilder<QStringBuilder<QStringBuilder<QStringBuilder<QStringBuilder<QStringBuilder<QStringBuilder<QLatin1Literal, QString>, QLatin1Literal>, QLatin1Char>, QLatin1Char>, QString>, QLatin1Literal>, QLatin1Char>, QLatin1Char>, QLatin1Literal>, QLatin1Char>, QLatin1Literal>, QLatin1Char>
-#else
-QString
-#endif
-constantString = QLatin1Literal( "(?:" ) + i18nOpen + doubleQuoteStringLiteral + i18nClose + QLatin1Char( '|' )
-                                                              + i18nOpen + singleQuoteStringLiteral + i18nClose + QLatin1Char( '|' )
-                                                              + doubleQuoteStringLiteral + QLatin1Char( '|' )
-                                                              + singleQuoteStringLiteral
-                                    + QLatin1Char( ')' );
+  const QString constantString = QLatin1Literal( "(?:" ) + i18nOpen + doubleQuoteStringLiteral + i18nClose + QLatin1Char( '|' )
+                                                         + i18nOpen + singleQuoteStringLiteral + i18nClose + QLatin1Char( '|' )
+                                                         + doubleQuoteStringLiteral + QLatin1Char( '|' )
+                                                         + singleQuoteStringLiteral
+                               + QLatin1Char( ')' );
 
-static const QString filterRawString = QLatin1Char( '^' ) + constantString + QLatin1Char( '|' )
-                                     + QLatin1Literal( "^[" ) + varChars + QLatin1Literal( "]+|" )
-                                     + numChars + QLatin1Char( '|' )
-                                     + filterSep + QLatin1Literal( "\\w+|" )
-                                     + argSep
-                                     + QLatin1Literal( "(?:" )
-                                       + constantString
-                                       + QLatin1Literal( "|[" )
-                                       + varChars
-                                       + QLatin1Literal( "]+|" )
-                                       + numChars
-                                       + QLatin1Char( '|' )
-                                       + filterSep
-                                     + QLatin1Literal( "\\w+)" );
+  const QString filterRawString = QLatin1Char( '^' ) + constantString + QLatin1Char( '|' )
+                               + QLatin1Literal( "^[" ) + varChars + QLatin1Literal( "]+|" )
+                               + numChars + QLatin1Char( '|' )
+                               + filterSep + QLatin1Literal( "\\w+|" )
+                               + argSep
+                               + QLatin1Literal( "(?:" )
+                                 + constantString
+                                 + QLatin1Literal( "|[" )
+                                 + varChars
+                                 + QLatin1Literal( "]+|" )
+                                 + numChars
+                                 + QLatin1Char( '|' )
+                                 + filterSep
+                               + QLatin1Literal( "\\w+)" );
 
-static const QRegExp sFilterRe( filterRawString );
+  return QRegExp( filterRawString );
+}
 
 FilterExpression::FilterExpression( const QString &varString, Parser *parser )
   : d_ptr( new FilterExpressionPrivate( this ) )
@@ -106,6 +104,8 @@ FilterExpression::FilterExpression( const QString &varString, Parser *parser )
 
   QString vs = varString;
 
+  static const QRegExp sFilterRe = getFilterRegexp();
+
   // This is one fo the few contstructors that can throw so we make sure to delete its d->pointer.
   try {
     while ( ( pos = sFilterRe.indexIn( vs, pos ) ) != -1 ) {
@@ -245,7 +245,7 @@ QVariant FilterExpression::resolve( Context *c ) const
 QVariantList FilterExpression::toList( Context *c ) const
 {
   const QVariant var = resolve( c );
-  return variantToList( var );
+  return MetaType::toVariantList( var );
 }
 
 bool FilterExpression::isTrue( Context *c ) const
