@@ -6,12 +6,12 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either version
-  2 of the Licence, or (at your option) any later version.
+  2.1 of the Licence, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
@@ -21,6 +21,8 @@
 #ifndef GRANTLEE_H
 #define GRANTLEE_H
 
+#include "grantlee/cachingloaderdecorator.h"
+#include "grantlee/containeraccessor.h"
 #include "grantlee/context.h"
 #include "grantlee/engine.h"
 #include "grantlee/exception.h"
@@ -28,13 +30,16 @@
 #include "grantlee/filterexpression.h"
 #include "grantlee/grantlee_core_export.h"
 #include "grantlee/grantlee_version.h"
+#include "grantlee/metatype.h"
 #include "grantlee/node.h"
 #include "grantlee/outputstream.h"
 #include "grantlee/parser.h"
+#include "grantlee/rendercontext.h"
 #include "grantlee/safestring.h"
 #include "grantlee/taglibraryinterface.h"
 #include "grantlee/template.h"
 #include "grantlee/templateloader.h"
+#include "grantlee/typeaccessor.h"
 #include "grantlee/token.h"
 #include "grantlee/util.h"
 #include "grantlee/variable.h"
