@@ -6,12 +6,12 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either version
-  2 of the Licence, or (at your option) any later version.
+  2.1 of the Licence, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
@@ -21,12 +21,12 @@
 
 #include "lexer_p.h"
 
+#include "grantlee_latin1literal_p.h"
+#include "grantlee_tags_p.h"
+
 #include <QtCore/QRegExp>
 #include <QtCore/QStringList>
 
-#include "grantlee_tags_p.h"
-#include "grantlee_latin1literal_p.h"
-
 using namespace Grantlee;
 
 static QRegExp getTagRe()
@@ -38,17 +38,17 @@ static QRegExp getTagRe()
   static const QLatin1Literal notEndOfLine( "[^\\n]*" );
 
   static const QString tagString = QLatin1Char( '(' )
-                                 + QRegExp::escape( BLOCK_TAG_START )
+                                 + QRegExp::escape( QLatin1String( BLOCK_TAG_START ) )
                                  + notEndOfLine
-                                 + QRegExp::escape( BLOCK_TAG_END )
+                                 + QRegExp::escape( QLatin1String( BLOCK_TAG_END ) )
                                  + QLatin1Char( '|' )
-                                 + QRegExp::escape( VARIABLE_TAG_START )
+                                 + QRegExp::escape( QLatin1String( VARIABLE_TAG_START ) )
                                  + notEndOfLine
-                                 + QRegExp::escape( VARIABLE_TAG_END )
+                                 + QRegExp::escape( QLatin1String( VARIABLE_TAG_END ) )
                                  + QLatin1Char( '|' )
-                                 + QRegExp::escape( COMMENT_TAG_START )
+                                 + QRegExp::escape( QLatin1String( COMMENT_TAG_START ) )
                                  + notEndOfLine
-                                 + QRegExp::escape( COMMENT_TAG_END )
+                                 + QRegExp::escape( QLatin1String( COMMENT_TAG_END ) )
                                  + QLatin1Char( ')' );
 
   static QRegExp sTagRe( tagString );
@@ -99,13 +99,13 @@ Token Lexer::createToken( const QString &fragment, State inTag, int *linecount )
     static const int startTagSize = 2;
     static const int endTagSize = 2;
     QString content = fragment.mid( startTagSize, fragment.size() - startTagSize - endTagSize );
-    if ( fragment.startsWith( VARIABLE_TAG_START ) ) {
+    if ( fragment.startsWith( QLatin1String( VARIABLE_TAG_START ) ) ) {
       token.tokenType = VariableToken;
       token.content = content.trimmed();
-    } else if ( fragment.startsWith( BLOCK_TAG_START ) ) {
+    } else if ( fragment.startsWith( QLatin1String( BLOCK_TAG_START ) ) ) {
       token.tokenType = BlockToken;
       token.content = content.trimmed();
-    } else if ( fragment.startsWith( COMMENT_TAG_START ) ) {
+    } else if ( fragment.startsWith( QLatin1String( COMMENT_TAG_START ) ) ) {
       token.tokenType = CommentToken;
       return token;
     }
