@@ -6,12 +6,12 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either version
-  2 of the Licence, or (at your option) any later version.
+  2.1 of the Licence, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
@@ -21,11 +21,12 @@
 #ifndef GRANTLEE_LEXER_P_H
 #define GRANTLEE_LEXER_P_H
 
-#include <QtCore/QList>
-#include <QtCore/QString>
-
 #include "token.h"
 
+// #include <QtCore/QList>
+
+template <typename T> class QList;
+
 namespace Grantlee
 {
 
