@@ -6,12 +6,12 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either version
-  2 of the Licence, or (at your option) any later version.
+  2.1 of the Licence, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
@@ -21,13 +21,14 @@
 #include "template.h"
 #include "template_p.h"
 
-#include <QtCore/QDebug>
-
-#include "lexer_p.h"
-#include "parser.h"
 #include "context.h"
 #include "engine.h"
 #include "exception.h"
+#include "lexer_p.h"
+#include "parser.h"
+#include "rendercontext.h"
+
+#include <QtCore/QDebug>
 
 using namespace Grantlee;
 
@@ -80,6 +81,9 @@ OutputStream* TemplateImpl::render( OutputStream *stream, Context *c )
   Q_D( Template );
 
   c->clearExternalMedia();
+
+  c->renderContext()->push();
+
   try {
     d->m_nodeList.render( stream, c );
   } catch ( Grantlee::Exception &e ) {
@@ -87,6 +91,8 @@ OutputStream* TemplateImpl::render( OutputStream *stream, Context *c )
     d->setError( e.errorCode(), e.what() );
   }
 
+  c->renderContext()->pop();
+
   return stream;
 }
 
