@@ -6,12 +6,12 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either version
-  2 of the Licence, or (at your option) any later version.
+  2.1 of the Licence, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
@@ -20,13 +20,12 @@
 
 #include "cycle.h"
 
-#include <QtCore/QStringList>
-#include "parser.h"
 #include "exception.h"
-
+#include "parser.h"
+#include "rendercontext.h"
 #include "util.h"
 
-static const char * _namedCycleNodes = "_namedCycleNodes";
+static const char _namedCycleNodes[] = "_namedCycleNodes";
 
 CycleNodeFactory::CycleNodeFactory()
 {
@@ -94,19 +93,30 @@ Node* CycleNodeFactory::getNode( const QString &tagContent, Parser *p ) const
   }
 }
 
-CycleNode::CycleNode( QList<FilterExpression> list, const QString &name, QObject *parent )
-    : Node( parent ), m_variableIterator( list )
+CycleNode::CycleNode( const QList<FilterExpression> &list, const QString &name, QObject *parent )
+    : Node( parent ), m_list( list ), m_variableIterator( list ), m_name( name )
 {
-  m_name = name;
 }
 
 void CycleNode::render( OutputStream *stream, Context *c )
 {
+  QVariant &variant = c->renderContext()->data( this );
+
+  FilterExpressionRotator rotator;
+
+  if ( variant.isValid() )
+    rotator = variant.value<FilterExpressionRotator>();
+  else
+    rotator = FilterExpressionRotator( m_list );
+
   QString value;
   QTextStream textStream( &value );
   QSharedPointer<OutputStream> temp = stream->clone( &textStream );
 
-  m_variableIterator.next().resolve( temp.data(), c );
+  rotator.next().resolve( temp.data(), c ).toString();
+
+  variant.setValue( rotator );
+
   if ( !m_name.isEmpty() ) {
     c->insert( m_name, value );
   }
