@@ -6,12 +6,12 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either version
-  2 of the Licence, or (at your option) any later version.
+  2.1 of the Licence, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
@@ -20,11 +20,8 @@
 
 #include "for.h"
 
-#include <QtCore/QStringList>
-
-#include "parser.h"
 #include "exception.h"
-
+#include "parser.h"
 
 ForNodeFactory::ForNodeFactory()
 {
@@ -105,18 +102,19 @@ void ForNode::setEmptyList( NodeList emptyList )
   m_emptyNodeList = emptyList;
 }
 
-// some magic variables injected into the context while rendering.
-static const QString forloop = QLatin1String( "forloop" );
-static const QString parentloop = QLatin1String( "parentloop" );
-static const QString counter0 = QLatin1String( "counter0" );
-static const QString counter = QLatin1String( "counter" );
-static const QString revcounter0 = QLatin1String( "revcounter0" );
-static const QString revcounter = QLatin1String( "revcounter" );
-static const QString first = QLatin1String( "first" );
-static const QString last = QLatin1String( "last" );
+static const char forloop[] = "forloop";
+static const char parentloop[] = "parentloop";
 
 void ForNode::insertLoopVariables( Context *c, int listSize, int i )
 {
+  // some magic variables injected into the context while rendering.
+  static const QString counter0 = QLatin1String( "counter0" );
+  static const QString counter = QLatin1String( "counter" );
+  static const QString revcounter0 = QLatin1String( "revcounter0" );
+  static const QString revcounter = QLatin1String( "revcounter" );
+  static const QString first = QLatin1String( "first" );
+  static const QString last = QLatin1String( "last" );
+
   QVariantHash forloopHash = c->lookup( QLatin1String( "forloop" ) ).toHash();
   forloopHash.insert( counter0, i );
   forloopHash.insert( counter, i + 1 );
@@ -124,7 +122,7 @@ void ForNode::insertLoopVariables( Context *c, int listSize, int i )
   forloopHash.insert( revcounter0, listSize - i - 1 );
   forloopHash.insert( first, ( i == 0 ) );
   forloopHash.insert( last, ( i == listSize - 1 ) );
-  c->insert( forloop, forloopHash );
+  c->insert( QLatin1String( forloop ), forloopHash );
 }
 
 void ForNode::renderLoop( OutputStream *stream, Context *c )
@@ -178,12 +176,12 @@ void ForNode::render( OutputStream *stream, Context *c )
 {
   QVariantHash forloopHash;
 
-  QVariant parentLoopVariant = c->lookup( forloop );
+  QVariant parentLoopVariant = c->lookup( QLatin1String( forloop ) );
   if ( parentLoopVariant.isValid() ) {
     // This is a nested loop.
     forloopHash = parentLoopVariant.toHash();
-    forloopHash.insert( parentloop, parentLoopVariant.toHash() );
-    c->insert( forloop, forloopHash );
+    forloopHash.insert( QLatin1String( parentloop ), parentLoopVariant.toHash() );
+    c->insert( QLatin1String( forloop ), forloopHash );
   }
 
   bool unpack = m_loopVars.size() > 1;
