@@ -6,12 +6,12 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either version
-  2 of the Licence, or (at your option) any later version.
+  2.1 of the Licence, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
@@ -20,10 +20,8 @@
 
 #include "regroup.h"
 
-#include <QtCore/QStringList>
-#include "parser.h"
 #include "exception.h"
-
+#include "parser.h"
 #include "util.h"
 
 RegroupNodeFactory::RegroupNodeFactory()
@@ -79,18 +77,14 @@ void RegroupNode::render( OutputStream *stream, Context *c )
   //
   // We then insert the objHash into the Context ready for rendering later in a for loop.
 
-  QVariantList list;
-  QVariantHash objHash;
   QVariantList contextList;
-  QString hashKey;
-  QString lastKey;
-  QString keyName = getSafeString( m_expression.resolve( c ) );
+  const QString keyName = getSafeString( m_expression.resolve( c ) );
   QListIterator<QVariant> i( objList );
   while ( i.hasNext() ) {
-    QVariant var = i.next();
+    const QVariant var = i.next();
     c->push();
     c->insert( QLatin1String( "var" ), var );
-    QString key = getSafeString( FilterExpression( QLatin1String( "var." ) + keyName, 0 ).resolve( c ) );
+    const QString key = getSafeString( FilterExpression( QLatin1String( "var." ) + keyName, 0 ).resolve( c ) );
     c->pop();
     QVariantHash hash;
     if ( contextList.size() > 0 ) {
