@@ -6,12 +6,12 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either version
-  2 of the Licence, or (at your option) any later version.
+  2.1 of the Licence, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
@@ -21,17 +21,16 @@
 #include "extends.h"
 
 #include "block.h"
-
-#include <QtCore/QStringList>
-
-#include "nodebuiltins_p.h"
-#include "parser.h"
-#include "template.h"
+#include "blockcontext.h"
 #include "engine.h"
 #include "exception.h"
+#include "nodebuiltins_p.h"
+#include "parser.h"
+#include "rendercontext.h"
+#include "template.h"
+#include "util.h"
 
 #include <QtCore/QListIterator>
-#include <util.h>
 
 using namespace Grantlee;
 
@@ -43,14 +42,14 @@ ExtendsNodeFactory::ExtendsNodeFactory( QObject *parent )
 
 Node* ExtendsNodeFactory::getNode( const QString &tagContent, Parser *p ) const
 {
-  QStringList expr = smartSplit( tagContent );
+  const QStringList expr = smartSplit( tagContent );
 
   if ( expr.size() != 2 )
     throw Grantlee::Exception( TagSyntaxError, QLatin1String( "Error: Include tag takes only one argument" ) );
 
   QString parentName = expr.at( 1 );
   FilterExpression fe;
-  int size = parentName.size();
+  const int size = parentName.size();
 
   if (( parentName.startsWith( QLatin1Char( '"' ) ) && parentName.endsWith( QLatin1Char( '\"' ) ) )
       || ( parentName.startsWith( QLatin1Char( '\'' ) ) && parentName.endsWith( QLatin1Char( '\'' ) ) ) ) {
@@ -67,7 +66,7 @@ Node* ExtendsNodeFactory::getNode( const QString &tagContent, Parser *p ) const
   if ( !t )
     throw Grantlee::Exception( TagSyntaxError, QLatin1String( "Extends tag is not in a template." ) );
 
-  NodeList nodeList = p->parse( t );
+  const NodeList nodeList = p->parse( t );
   n->setNodeList( nodeList );
 
   if ( t->findChildren<ExtendsNode *>().size() > 1 ) {
@@ -89,20 +88,36 @@ ExtendsNode::~ExtendsNode()
 {
 }
 
+static QHash<QString, BlockNode*> createNodeMap( QList<BlockNode*> list )
+{
+  QHash<QString, BlockNode*> map;
 
-void ExtendsNode::setNodeList( NodeList list )
+  QList<BlockNode*>::const_iterator it = list.constBegin();
+  const QList<BlockNode*>::const_iterator end = list.constEnd();
+
+  for ( ; it != end; ++it )
+  {
+    map.insert( ( *it )->name(), *it );
+  }
+
+  return map;
+}
+
+void ExtendsNode::setNodeList( const NodeList &list )
 {
   m_list = list;
+
+  const QList<BlockNode*> blockList = m_list.findChildren<BlockNode*>();
+  m_blocks = createNodeMap( blockList );
 }
 
 Template ExtendsNode::getParent( Context *c )
 {
   QString parentName;
   if ( m_name.isEmpty() ) {
-    QVariant parentVar = m_filterExpression.resolve( c );
+    const QVariant parentVar = m_filterExpression.resolve( c );
     if ( parentVar.userType() == qMetaTypeId<Grantlee::Template>() ) {
-      Template parentTemplate = parentVar.value<Template>();
-      return parentTemplate;
+      return parentVar.value<Template>();
     }
 
     parentName = getSafeString( parentVar );
@@ -112,7 +127,7 @@ Template ExtendsNode::getParent( Context *c )
 
   TemplateImpl *ti = containerTemplate();
 
-  Template t = ti->engine()->loadByName( parentName );
+  const Template t = ti->engine()->loadByName( parentName );
 
   if ( !t )
     throw Grantlee::Exception( TagSyntaxError, QString::fromLatin1( "Template not found %1" ).arg( parentName ) );
@@ -131,42 +146,30 @@ void ExtendsNode::render( OutputStream *stream, Context *c )
     throw Grantlee::Exception( TagSyntaxError, QString::fromLatin1( "Cannot load template '%1'" ).arg( m_name ) );
   }
 
-  QList<BlockNode*> nodeList = m_parentTemplate->findChildren<BlockNode *>();
+  QVariant &variant = c->renderContext()->data( 0 );
+  BlockContext blockContext = variant.value<BlockContext>();
+  blockContext.addBlocks( m_blocks );
+  variant.setValue( blockContext );
 
-  QHash<QString, BlockNode *> parentBlocks;
+  const NodeList nodeList = m_parentTemplate->nodeList();
 
-  QListIterator<BlockNode *> i( nodeList );
+  const QHash<QString, BlockNode*> parentBlocks = createNodeMap( m_parentTemplate->findChildren<BlockNode*>() );
+  QListIterator<Node*> i( nodeList );
 
   while ( i.hasNext() ) {
-    BlockNode* bn = i.next();
-    parentBlocks.insert( bn->name(), bn );
-  }
-
-  QList<BlockNode*> l = parent()->findChildren<BlockNode *>();
-  QListIterator<BlockNode *> j( l );
-
-  while ( j.hasNext() ) {
-    BlockNode *bn = j.next();
-    if ( parentBlocks.contains( bn->name() ) ) {
-      BlockNode *pbn = parentBlocks.value( bn->name() );
-      pbn->setNodeParent( bn->takeNodeParent() );
-      pbn->addParent( pbn->nodeList() );
-      pbn->setNodeList( bn->nodeList() );
-    } else {
-      Q_FOREACH( Node *node, m_parentTemplate->nodeList() ) {
-        TextNode *tn = qobject_cast<TextNode*>( node );
-        if ( !tn ) {
-          ExtendsNode *en = qobject_cast<ExtendsNode*>( node );
-          if ( en ) {
-            en->appendNode( bn );
-          }
-          break;
-        }
+    Node* n = i.next();
+    TextNode *tn = qobject_cast<TextNode*>( n );
+    if ( !tn ) {
+      ExtendsNode *en = qobject_cast<ExtendsNode*>( n );
+      if ( !en ) {
+        blockContext.addBlocks( parentBlocks );
+        variant.setValue( blockContext );
       }
+      break;
     }
   }
-
-  m_parentTemplate->render( stream, c );
+  variant.setValue( blockContext );
+  m_parentTemplate->nodeList().render( stream, c );
 }
 
 void ExtendsNode::appendNode( Node *node )
