@@ -6,12 +6,12 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either version
-  2 of the Licence, or (at your option) any later version.
+  2.1 of the Licence, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
@@ -241,6 +241,9 @@ private Q_SLOTS:
   void testMediaPathSafety_data();
   void testMediaPathSafety();
 
+  void testDynamicProperties_data();
+  void testDynamicProperties() { doTest(); }
+
   void cleanupTestCase();
 
 private:
@@ -622,6 +625,15 @@ void TestBuiltinSyntax::testListIndex_data()
   QTest::newRow( "list-index05" ) << QString::fromLatin1( "{{ var.1 }}" ) << dict << QString::fromLatin1( "hello" ) << NoError;
 
   // QVariantHash can only use strings as keys, so list-index06 and list-index07 are not valid.
+
+  dict.clear();
+
+  QStringList sl;
+  sl.append( QLatin1String( "hello" ) );
+  sl.append( QLatin1String( "world" ) );
+  dict.insert( QLatin1String( "var" ), sl );
+  // QStringList lookup
+  QTest::newRow( "list-index08" ) << QString::fromLatin1( "{{ var.0 }}, {{ var.1 }}!" ) << dict << QString::fromLatin1( "hello, world!" ) << NoError;
 }
 
 
@@ -1088,7 +1100,7 @@ void TestBuiltinSyntax::testTypeAccessors_data()
 
   dict.clear();
 
-#define SON(obj) obj->setObjectName(#obj)
+#define SON(obj) obj->setObjectName( QLatin1String( #obj ) )
 
   QObject *obj1 = new QObject(this);
   SON(obj1);
@@ -1102,7 +1114,7 @@ void TestBuiltinSyntax::testTypeAccessors_data()
   obj4->setParent(obj2);
   SON(obj4);
 
-  dict.insert("object", QVariant::fromValue( obj1 ) );
+  dict.insert( QLatin1String( "object" ), QVariant::fromValue( obj1 ) );
 
   QTest::newRow( "type-accessors-qobject01" ) << QString::fromLatin1( "{{ object.objectName }}" ) << dict << QString::fromLatin1( "obj1" ) << NoError;
 
@@ -1131,6 +1143,24 @@ void TestBuiltinSyntax::testTypeAccessors_data()
 
 }
 
+void TestBuiltinSyntax::testDynamicProperties_data()
+{
+  QTest::addColumn<QString>( "input" );
+  QTest::addColumn<Dict>( "dict" );
+  QTest::addColumn<QString>( "output" );
+  QTest::addColumn<Grantlee::Error>( "error" );
+
+  Dict dict;
+
+  QObject *obj = new QObject( this );
+  obj->setProperty( "prop", 7 );
+  dict.insert( QLatin1String( "var" ), QVariant::fromValue( static_cast<QObject*>( obj ) ) );
+
+  QTest::newRow( "dynamic-properties01" ) << QString::fromLatin1( "{{ var.prop }}" ) << dict << QString::fromLatin1( "7" ) << NoError;
+
+}
+
+
 
 QTEST_MAIN( TestBuiltinSyntax )
 #include "testbuiltins.moc"
